@@ -126,24 +126,26 @@ path                                  A :any:`Path <matplotlib.path.Path>`
 
 from alpsplot.utils import group_err_bar
 
+from matplotlib import ticker
+from matplotlib import pyplot as plt
+
 import os
 import numpy as np
 
-import matplotlib.figure as figure
-from matplotlib import ticker
-from matplotlib import pyplot as plt
-from matplotlib.axes import Axes
-from matplotlib.lines import Line2D
-from matplotlib.container import BarContainer
-from matplotlib.collections import PathCollection
 from typing import Sequence, Union
 from typing import TYPE_CHECKING
-if TYPE_CHECKING:
-    pass    # TODO: python 3.10
+if TYPE_CHECKING:    # TODO: python 3.11
+    import matplotlib.figure as figure
+    from matplotlib.axes import Axes
+    from matplotlib.lines import Line2D
+    from matplotlib.container import BarContainer
+    from matplotlib.collections import PathCollection
 
 # TODO: We could use default values after matplotlib 3.5.0
 # https://github.com/matplotlib/matplotlib/pull/20101
 
+__all__ = ['Figure']
+
 
 class Figure:
     r"""The Figure wrapper class.
@@ -151,7 +153,7 @@ class Figure:
     Args:
         name (str): Figure name used as default value of
             :meth:`save` and :meth:`set_title`.
-        folder_path (str): Figure name used as default value of :meth:`save`.
+        folder_path (str): Folder path used as default value of :meth:`save`.
             Defaults to ``'./output/'``.
         fig (~matplotlib.figure.Figure, optional): The pre-defined Figure.
             Otherwise, call :any:`pyplot.figure() <matplotlib.pyplot.figure>`
@@ -172,22 +174,22 @@ class Figure:
     Attributes:
         name (str): Figure name used as default value of
             :meth:`save` and :meth:`set_title`.
-        folder_path (str): Figure name used as default value of :meth:`save`.
+        folder_path (str): Folder path used as default value of :meth:`save`.
             Defaults to ``'./output/'``.
         fig (~matplotlib.figure.Figure): Figure object.
         ax (~matplotlib.axes.Axes): Axes object.
     """
 
     def __init__(self, name: str, folder_path: str = './output/',
-                 fig: figure.Figure = None, ax: Axes = None,
+                 fig: 'figure.Figure' = None, ax: 'Axes' = None,
                  figsize: tuple[float, float] = (5, 2.5), **kwargs):
         self.name: str = name
         self.folder_path: str = folder_path
-        self.fig: Figure = fig
-        self.ax: Axes = ax
         if fig is None and ax is None:
-            self.fig: Figure = plt.figure(figsize=figsize, **kwargs)
-            self.ax = self.fig.add_subplot(1, 1, 1)
+            fig: 'figure.Figure' = plt.figure(figsize=figsize, **kwargs)
+            ax = fig.add_subplot(1, 1, 1)
+        self.fig: 'figure.Figure' = fig
+        self.ax: 'Axes' = ax
         self.ax.spines['top'].set_visible(False)
         self.ax.spines['bottom'].set_visible(True)
         self.ax.spines['left'].set_visible(False)
@@ -203,7 +205,7 @@ class Figure:
         r"""Class methods are similar to regular functions.
 
         Args:
-            path (str, optional): The filepath to save the figure.
+            path (str, optional): The file path to save the figure.
                 Defaults to ``f'{folder_path}/{filename}'``.
             folder_path (str, optional): Called when :attr:`path` is ``None``.
                 Defaults to :attr:`~self.folder_path`.
@@ -260,29 +262,19 @@ class Figure:
             os.makedirs(folder_path)
         self.fig.savefig(path, dpi=dpi, bbox_inches=bbox_inches, **kwargs)
 
-    def set_title(self, text: str = None, fontsize: int = 16,
-                  fontproperties: str = 'Optima', fontweight: str = 'bold',
-                  math_fontfamily: str = 'cm', **kwargs):
+    def set_title(self, text: str = None, **kwargs):
         r"""Call :any:`Axes.set_title() <matplotlib.axes.Axes.set_title>`.
 
         Args:
             text (str, optional): The text of title.
                 Defaults to :attr:`self.name`.
-
-        ..
-
-        Args:
-            fontsize (int): The fontsize of text.
-                Defaults to ``16``.
-            fontproperties (str): The font of text.
-                Defaults to ``'Optima'``.
-            fontweight (str): The fontweight of text.
-                Defaults to ``'bold'``.
-            math_fontfamily (str): The math_fontfamily of text.
-                Defaults to ``'cm'``.
             **kwargs: Keyword arguments passed to
                 :any:`Axes.set_title() <matplotlib.axes.Axes.set_title>`.
 
+        Returns:
+            ~matplotlib.text.Text:
+                The matplotlib text instance representing the title.
+
         :Example:
             .. code-block:: python
                 :emphasize-lines: 5
@@ -298,13 +290,9 @@ class Figure:
                 :width: 60%
         """
         text = self.name if text is None else text
-        self.ax.set_title(text, fontsize=fontsize,
-                          fontproperties=fontproperties, fontweight=fontweight,
-                          math_fontfamily=math_fontfamily, **kwargs)
+        return self.ax.set_title(text, **kwargs)
 
-    def set_axis_label(self, axis: str, text: str, fontsize: int = 12,
-                       fontproperties: str = 'Optima', fontweight='bold',
-                       math_fontfamily: str = 'cm', **kwargs):
+    def set_axis_label(self, axis: str, text: str, **kwargs):
         r"""Call :any:`Axes.set_xlabel() <matplotlib.axes.Axes.set_xlabel>`
         or :any:`Axes.set_ylabel() <matplotlib.axes.Axes.set_ylabel>`.
 
@@ -312,22 +300,14 @@ class Figure:
             axis (str): The axis to set label.
                 Possible values: ``['x', 'y', 'z']``.
             text (str): The text of axis label.
-
-        ..
-
-        Args:
-            fontsize (int): The fontsize of text.
-                Defaults to ``12``.
-            fontproperties (str): The font of text.
-                Defaults to ``'Optima'``.
-            fontweight (str): The fontweight of text.
-                Defaults to ``'bold'``.
-            math_fontfamily (str): The math_fontfamily of text.
-                Defaults to ``'cm'``.
             **kwargs: Keyword arguments passed to
                 :any:`Axes.set_xlabel() <matplotlib.axes.Axes.set_xlabel>`
                 or :any:`Axes.set_ylabel() <matplotlib.axes.Axes.set_ylabel>`.
 
+        Returns:
+            ~matplotlib.text.Text:
+                The matplotlib text instance representing the axis label.
+
         :Example:
             .. code-block:: python
                 :emphasize-lines: 5-6
@@ -344,18 +324,13 @@ class Figure:
                 :width: 60%
         """
         func = getattr(self.ax, f'set_{axis}label')
-        func(text, fontsize=fontsize, fontproperties=fontproperties,
-             fontweight=fontweight, math_fontfamily=math_fontfamily,
-             **kwargs)
+        return func(text, **kwargs)
 
     def set_axis_lim(self, axis: str, labels: list[str] = None,
                      lim: tuple[float, float] = (0.0, 1.0),
                      margin: tuple[float, tuple] = (0.0, 0.0),
                      piece: int = 10, _format: str = '%.1f',
-                     fontsize: int = 11,
-                     fontproperties: str = 'Optima',
-                     fontweight: str = 'bold',
-                     math_fontfamily: str = 'cm', **kwargs):
+                     **kwargs):
         r"""Set ticks and their labels for axis.
 
         .. table::
@@ -375,7 +350,7 @@ class Figure:
         .. parsed-literal::
             set_lim(lim[0] - margin[0], lim[1] + margin[1])
             set_ticks(lim[0], lim[0] + :math:`\frac{1}{\text{lim}[1] - \text{lim}[0]}`, :math:`\dots`, lim[1])
-            set_ticklabels(labels, \*\*fontargs, \*\*kwargs)
+            set_ticklabels(labels, \*\*kwargs)
             format_str = :any:`ticker.FormatStrFormatter <matplotlib.ticker.FormatStrFormatter>`\(_format)
             :any:`Axis.set_major_formatter <matplotlib.axis.Axis.set_major_formatter>`\(format_str)
 
@@ -395,18 +370,6 @@ class Figure:
                 Defaults to ``10``.
             _format (str): The format of tick labels.
                 Defaults to ``'%.1f'``.
-
-        ..
-
-        Args:
-            fontsize (int): The fontsize of text.
-                Defaults to ``11``.
-            fontproperties (str): The font of text.
-                Defaults to ``'Optima'``.
-            fontweight (str): The fontweight of text.
-                Defaults to ``'bold'``.
-            math_fontfamily (str): The math_fontfamily of text.
-                Defaults to ``'cm'``.
             **kwargs: Keyword arguments passed to
                 :any:`Axes.set_xticklabels()
                 <matplotlib.axes.Axes.set_xticklabels>`
@@ -439,25 +402,18 @@ class Figure:
         getattr(self.ax, f'set_{axis}lim')(*final_lim)
         getattr(self.ax, f'set_{axis}ticks')(ticks)
         set_ticklabels_func = getattr(self.ax, f'set_{axis}ticklabels')
-        font_args = dict(fontsize=fontsize,
-                         fontproperties=fontproperties,
-                         fontweight=fontweight,
-                         math_fontfamily=math_fontfamily)
         if labels is None:
             labels = getattr(self.ax, f'get_{axis}ticks')()
-            set_ticklabels_func(labels, **font_args, **kwargs)
+            set_ticklabels_func(labels, **kwargs)
             getattr(self.ax, f'{axis}axis').set_major_formatter(
                 ticker.FormatStrFormatter(_format))
         else:
-            set_ticklabels_func(labels, **font_args, **kwargs)
+            set_ticklabels_func(labels, **kwargs)
 
     def set_legend(self, *args, frameon: bool = None,
                    framealpha: float = 1.0,
                    edgecolor: str = 'none',
-                   fontsize: int = 11,
-                   fontproperties: str = 'Optima',
-                   fontstyle: str = None, fontweight='bold',
-                   math_fontfamily: str = 'cm', **kwargs) -> None:
+                   **kwargs) -> None:
         r"""Call :any:`Axes.legend() <matplotlib.axes.Axes.legend>`
         to set legend of :attr:`self.ax`.
 
@@ -474,23 +430,12 @@ class Figure:
                 Defaults to ``0.0``.
             edgecolor (str): The legend's background patch edge color.
                 Defaults to ``'none'``.
-
-        ..
-
-        Args:
-            fontsize (int): The fontsize of text.
-                Defaults to ``11``.
-            fontproperties (str): The font of text.
-                Defaults to ``'Optima'``.
-            fontstyle (str): The font style of text.
-                Defaults to ``None``.
-            fontweight (str): The fontweight of text.
-                Defaults to ``'bold'``.
-            math_fontfamily (str): The math_fontfamily of text.
-                Defaults to ``'cm'``.
             **kwargs: Keyword arguments passed to
                 :any:`Axes.legend() <matplotlib.axes.Axes.legend>`.
 
+        Returns:
+            ~matplotlib.legend.Legend: The matplotlib legend instance.
+
         :Example:
             .. code-block:: python
                 :emphasize-lines: 16
@@ -516,20 +461,19 @@ class Figure:
             .. image:: /images/figure/set_legend.svg
                 :width: 60%
         """
-        self.ax.legend(*args, frameon=frameon, edgecolor=edgecolor,
-                       framealpha=framealpha, **kwargs)
-        plt.setp(self.ax.get_legend().get_texts(), fontsize=fontsize,
-                 fontproperties=fontproperties,
-                 fontstyle=fontstyle, fontweight=fontweight,
-                 math_fontfamily=math_fontfamily)
+        legend = self.ax.legend(*args, frameon=frameon, edgecolor=edgecolor,
+                                framealpha=framealpha, **kwargs)
+        return legend
 
     def lineplot(self, x: np.ndarray, y: np.ndarray,
                  err: np.array = None, err_style: str = 'band',
                  color: str = 'black', alpha: float = 1.0,
                  linewidth: int = 2, linestyle: str = '-',
                  label: str = None, markerfacecolor: str = 'white',
-                 zorder: float = 1, **kwargs) -> Line2D:
+                 zorder: float = 1, **kwargs) -> 'Line2D':
         r"""A similar implementation to :any:`seaborn.lineplot() <seaborn.lineplot>`.
+        same x value with different y values will result in
+        the error band/bar at that x.
 
         Args:
             x (numpy.ndarray): The x array.
@@ -563,9 +507,13 @@ class Figure:
             **kwargs: Keyword arguments passed to
                 :any:`Axes.plot() <matplotlib.axes.Axes.plot>`.
 
+        Returns:
+            list[matplotlib.lines.Line2D]:
+                A list of lines representing the plotted data.
+
         :Example:
             .. code-block:: python
-                :emphasize-lines: 14, 20, 26-27
+                :emphasize-lines: 14, 20, 25-26
 
                 import numpy as np
                 from alpsplot.figure import Figure
@@ -582,17 +530,16 @@ class Figure:
                 y = np.arange(10, step=0.5)
                 fig.lineplot(x, y, color='red', label='plain')
 
-                x = np.concatenate((x, x, x))
+                x_err = np.concatenate((x, x, x))
                 noise = np.random.randn(20)
                 y_mean = y / 2
                 y_err = np.concatenate((y_mean-noise, y_mean, y_mean+noise))
-                fig.lineplot(x, y_err, color='green', label='error band')
+                fig.lineplot(x_err, y_err, color='green', label='error band')
 
-                x = np.concatenate((x, x, x))
                 noise = np.random.randn(20)
                 y_mean = y / 2 + 4
                 y_err = np.concatenate((y_mean-noise, y_mean, y_mean+noise))
-                fig.lineplot(x, y_err, color='blue', label='error bar',
+                fig.lineplot(x_err, y_err, color='blue', label='error bar',
                              err_style='bars')
 
                 fig.set_legend()
@@ -608,14 +555,17 @@ class Figure:
             y = np.array([y_list.mean() for y_list in y_dict.values()])
             err = np.array([y_list.std() for y_list in y_dict.values()])
         if err is not None:
-            if err_style == 'band':  # TODO: python 3.10
-                self.ax.fill_between(x=x, y1=y-err, y2=y+err,
-                                     color=color, alpha=alpha*0.2,
+            match err_style:
+                case 'band':
+                    self.ax.fill_between(x=x, y1=y-err, y2=y+err,
+                                         color=color, alpha=alpha*0.2,
+                                         zorder=zorder)
+                case 'bars':
+                    self.ax.errorbar(x=x, y=y, yerr=err,
+                                     color=color, alpha=alpha, linestyle="",
                                      zorder=zorder)
-            elif err_style == 'bars':
-                self.ax.errorbar(x=x, y=y, yerr=err,
-                                 color=color, alpha=alpha, linestyle="",
-                                 zorder=zorder)
+                case _:
+                    raise ValueError(f'{err_style=}')
         return self.ax.plot(x, y, color=color, alpha=alpha,
                             linewidth=linewidth, linestyle=linestyle,
                             label=label, markerfacecolor=markerfacecolor,
@@ -623,7 +573,7 @@ class Figure:
 
     def curve_legend(self, label: str = None, color: str = 'black',
                      linewidth: int = 2, linestyle: str = '-',
-                     markerfacecolor: str = 'white', **kwargs) -> Line2D:
+                     markerfacecolor: str = 'white', **kwargs) -> 'Line2D':
         r"""Call :any:`Axes.plot() <matplotlib.axes.Axes.plot>`
         to plot an empty line for legend,
 
@@ -644,6 +594,9 @@ class Figure:
             **kwargs: Keyword arguments passed to
                 :any:`Axes.plot() <matplotlib.axes.Axes.plot>`.
 
+        Returns:
+            ~matplotlib.lines.Line2D: An invisible line object.
+
         :Example:
             .. code-block:: python
                 :emphasize-lines: 5-6
@@ -671,7 +624,7 @@ class Figure:
                 color: str = 'black', linewidth: int = 2,
                 marker: str = 'D', facecolor: str = 'white',
                 label: str = None, curve_legend: bool = False,
-                zorder: float = 3, **kwargs) -> PathCollection:
+                zorder: float = 3, **kwargs) -> 'PathCollection':
         r"""Call :any:`Axes.scatter() <matplotlib.axes.Axes.scatter>`
         to plot scatters.
 
@@ -697,6 +650,9 @@ class Figure:
             **kwargs: Keyword arguments passed to
                 :any:`Axes.scatter() <matplotlib.axes.Axes.scatter>`.
 
+        Returns:
+            ~matplotlib.collections.PathCollection: A collection of Paths.
+
         :Example:
             .. code-block:: python
                 :emphasize-lines: 14-16
@@ -735,7 +691,7 @@ class Figure:
     def bar(self, x: np.ndarray, y: np.ndarray, width: float = 0.8,
             color: str = 'black', edgecolor: str = 'white',
             align: str = 'edge', linewidth: int = 1,
-            label: str = None, **kwargs) -> BarContainer:
+            label: str = None, **kwargs) -> 'BarContainer':
         r"""Call :any:`Axes.bar() <matplotlib.axes.Axes.bar>`
         to plot bars.
 
@@ -765,6 +721,10 @@ class Figure:
             **kwargs: Keyword arguments passed to
                 :any:`Axes.bar() <matplotlib.axes.Axes.bar>`.
 
+        Returns:
+            ~matplotlib.container.BarContainer:
+                Container with all the bars and optionally errorbars.
+
         :Example:
             .. code-block:: python
                 :emphasize-lines: 14-15
@@ -851,9 +811,13 @@ class Figure:
             **kwargs: Keyword arguments passed to
                 :any:`Axes.hist() <matplotlib.axes.Axes.hist>`.
 
+        Returns:
+            ~matplotlib.container.BarContainer:
+                Container with all the bars and optionally errorbars.
+
         :Example:
             .. code-block:: python
-                :emphasize-lines: 15-16
+                :emphasize-lines: 13-14
 
                 import numpy as np
                 from alpsplot.figure import Figure
@@ -879,12 +843,9 @@ class Figure:
                             facecolor=facecolor, edgecolor=edgecolor,
                             linewidth=linewidth, **kwargs)
 
-    def autolabel(self, rects: BarContainer,
+    def autolabel(self, rects: 'BarContainer',
                   offset: float = None, above: bool = True,
-                  fontsize: int = 7, fontproperties: str = 'Optima',
-                  fontweight: str = 'bold',
-                  math_fontfamily: str = 'cm',
-                  **kwargs) -> None:
+                  fontsize: int = 7, **kwargs) -> None:
         r"""Call :any:`Axes.annotate() <matplotlib.axes.Axes.annotate>`
         to attach a text label above each bar in :attr:`rects`,
         displaying its height.
@@ -897,18 +858,8 @@ class Figure:
                 Defaults to ``None``.
             above (bool): Whether to put the text above the rects.
                 Defaults to ``True``.
-
-        ..
-
-        Args:
             fontsize (int): The fontsize of text.
                 Defaults to ``7``.
-            fontproperties (str): The font of text.
-                Defaults to ``'Optima'``.
-            fontweight (str): The fontweight of text.
-                Defaults to ``'bold'``.
-            math_fontfamily (str): The math_fontfamily of text.
-                Defaults to ``'cm'``.
             **kwargs: Keyword arguments passed to
                 :any:`Axes.annotate() <matplotlib.axes.Axes.annotate>`.
 
@@ -948,15 +899,12 @@ class Figure:
                              xy=(rect.get_x() + rect.get_width() / 2, height),
                              xytext=(0, offset),  # 3 points vertical offset
                              textcoords="offset points",
-                             ha='center', va='bottom', fontsize=fontsize,
-                             fontproperties=fontproperties,
-                             fontweight=fontweight,
-                             math_fontfamily=math_fontfamily,
-                             **kwargs)
+                             ha='center', va='bottom',
+                             fontsize=fontsize, **kwargs)
 
     # def bar3d(self, x: np.ndarray, y: np.ndarray, z: np.ndarray,
     #           color: str = 'black', size: tuple[float, float] = 0.5,
-    #           label: str = None, **kwargs) -> BarContainer:
+    #           label: str = None, **kwargs) -> 'BarContainer':
     #     # facecolor edgewidth alpha
     #     if isinstance(size, (float, int)):
     #         size = [size, size]
